@@ -448,9 +448,9 @@ plotPercentiles <- function(model,
                             subtitle = NULL,
                             points = F) {
 
-  is_beta_binomial <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")
-  if(is_beta_binomial){
-    stop("This function is not applicable for beta-binomial models. Please use 'plot(model.binomial, age, raw)' instead.")
+  is_parametric <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")||inherits(model, "cnormShaSh")
+  if(is_parametric){
+    stop("This function is not applicable for parametric models (Beta Binomial or Sinh-Arcsinh). Please use 'plot(model, age, raw)' instead.")
   }
 
   if(inherits(model, "cnorm")){
@@ -651,7 +651,8 @@ plotPercentiles <- function(model,
 #' It supports both traditional continuous norming models and beta-binomial models.
 #' The function allows for customization of the plot range and groups to be displayed.
 #'
-#' @param model The model from the bestModel function, a cnorm object, or a cnormBetaBinomial or cnormBetaBinomial2 object.
+#' @param model The model from the bestModel function, a cnorm object, a cnormBetaBinomial, a cnormBetaBinomial2 or
+#'    cnormShaSh object.
 #' @param minRaw Lower bound of the raw score. If NULL, it's automatically determined based on the model type.
 #' @param maxRaw Upper bound of the raw score. If NULL, it's automatically determined based on the model type.
 #' @param minNorm Lower bound of the norm score. If NULL, it's automatically determined based on the model type.
@@ -699,6 +700,7 @@ plotDensity <- function(model,
   }
 
   is_beta_binomial <- inherits(model, "cnormBetaBinomial")||inherits(model, "cnormBetaBinomial2")
+  is_shash <- inherits(model, "cnormShaSh")
 
   if (is.null(minNorm)) {
     minNorm <- if(is_beta_binomial) -3 else model$minL1
@@ -719,7 +721,7 @@ plotDensity <- function(model,
 
 
   if (is.null(group)) {
-    if(is_beta_binomial) {
+    if(is_beta_binomial||is_shash) {
       age_min <- attr(model$result, "ageMin")
       age_max <- attr(model$result, "ageMax")
       group <- round(seq(from = age_min, to = age_max, length.out = 4), digits = 3)
@@ -739,6 +741,12 @@ plotDensity <- function(model,
       colnames(norm)[colnames(norm) == "x"] <- "raw"
       colnames(norm)[colnames(norm) == "norm"] <- "norm1"
       colnames(norm)[colnames(norm) == "z"] <- "norm"
+    } else if(is_shash) {
+      norm <- normTable.shash(model, g, attr(model$result, "max"))[[1]]
+      norm$group <- rep(g, length.out = nrow(norm))
+      colnames(norm)[colnames(norm) == "x"] <- "raw"
+      colnames(norm)[colnames(norm) == "norm"] <- "norm1"
+      colnames(norm)[colnames(norm) == "z"] <- "norm"
     } else {
       norm <- normTable(g, model = model, minNorm = minNorm, maxNorm = maxNorm, minRaw = minRaw, maxRaw = maxRaw, step = step, pretty = FALSE)
       norm$group <- rep(g, length.out = nrow(norm))
@@ -820,9 +828,9 @@ plotPercentileSeries <- function(model, start = 1, end = NULL, group = NULL,
                                  percentiles = c(0.025, 0.1, 0.25, 0.5, 0.75, 0.9, 0.975),
                                  filename = NULL) {
 
-  is_beta_binomial <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")
-  if(is_beta_binomial){
-    stop("This function is not applicable for beta-binomial models. Please use the plotDensity function instead.")
+  is_parametric <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")||inherits(model, "cnormShaSh")
+  if(is_parametric){
+    stop("This function is not applicable for parametric models (Beta Binomial or Sinh-Arcsinh). Please use the plotDensity function instead.")
   }
 
   if(inherits(model, "cnorm")){
@@ -980,8 +988,9 @@ plotPercentileSeries <- function(model, start = 1, end = NULL, group = NULL,
 #' @family plot
 plotSubset <- function(model, type = 0) {
 
-  if(inherits(model, "cnormBetaBinomial2") || inherits(model, "cnormBetaBinomial")){
-    stop("This function is not applicable for beta-binomial models.")
+  is_parametric <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")||inherits(model, "cnormShaSh")
+  if(is_parametric){
+    stop("This function is not applicable for parametric models (Beta Binomial or Sinh-Arcsinh).")
   }
 
   if(inherits(model, "cnorm")){
@@ -1169,9 +1178,9 @@ plotDerivative <- function(model,
     model <- model$model
   }
 
-  is_beta_binomial <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")
-  if(is_beta_binomial){
-    stop("This function is not applicable for beta-binomial models. Please use the plotDensity function instead.")
+  is_parametric <- inherits(model, "cnormBetaBinomial2")||inherits(model, "cnormBetaBinomial")||inherits(model, "cnormShaSh")
+  if(is_parametric){
+    stop("This function is not applicable for parametric models (Beta Binomial or Sinh-Arcsinh). Please use the plotDensity function instead.")
   }
 
   if (!model$useAge){
@@ -1297,11 +1306,11 @@ plotCnorm <- function(x, y, ...){
 #' This function creates a visualization comparing two norm models by displaying
 #' their percentile curves. The first model is shown with solid lines, the second
 #' with dashed lines. If age and score vectors are provided, manifest percentiles
-#' are displayed as dots. The function works with both regular cnorm models and
-#' beta-binomial models and allows comparison between different model types.
+#' are displayed as dots. The function works with regular cnorm models, beta-binomial
+#' models, and ShaSh models, allowing comparison between different model types.
 #'
-#' @param model1 First model object (distribution free or beta-binomial)
-#' @param model2 Second model object (distribution free or beta-binomial)
+#' @param model1 First model object (distribution free, beta-binomial, or ShaSh)
+#' @param model2 Second model object (distribution free, beta-binomial, or ShaSh)
 #' @param age Optional vector with manifest age or group values
 #' @param score Optional vector with manifest raw score values
 #' @param weights Optional vector with manifest weights
@@ -1316,7 +1325,13 @@ plotCnorm <- function(x, y, ...){
 #' # Compare different types of models
 #' model1 <- cnorm(group = elfe$group, raw = elfe$raw)
 #' model2 <- cnorm.betabinomial(elfe$group, elfe$raw)
-#' compare(model1, model2, age = elfe$group, score = elfe$raw)
+#' model3 <- cnorm.shash(elfe$group, elfe$raw)
+#'
+#' # Compare traditional cnorm with ShaSh
+#' compare(model1, model3, age = elfe$group, score = elfe$raw)
+#'
+#' # Compare beta-binomial with ShaSh
+#' compare(model2, model3, age = elfe$group, score = elfe$raw)
 #' }
 #'
 #' @export
@@ -1329,7 +1344,7 @@ compare <- function(model1, model2,
                     title = NULL,
                     subtitle = NULL) {
 
-  # retrieve score from model if score is null and of of the
+  # retrieve score from model if score is null and one of the
   # models is a cnorm object
   if(is.null(score) && inherits(model1, "cnorm")){
     score <- model1$data[[attributes(model1$data)$raw]]
@@ -1337,8 +1352,8 @@ compare <- function(model1, model2,
   }
 
   if(is.null(score) && inherits(model2, "cnorm")){
-    score <- model1$data[[attributes(model1$data)$raw]]
-    age <- model1$data[[attributes(model1$data)$age]]
+    score <- model2$data[[attributes(model2$data)$raw]]
+    age <- model2$data[[attributes(model2$data)$age]]
   }
 
   # Function to get predictions for beta-binomial models
@@ -1361,6 +1376,24 @@ compare <- function(model1, model2,
     return(pred_data)
   }
 
+  # Function to get predictions for ShaSh models
+  get_shash_predictions <- function(model, pred_ages) {
+    preds <- predictCoefficients_shash(model, pred_ages)
+
+    pred_matrix <- matrix(NA, nrow = length(pred_ages), ncol = length(percentiles))
+    for(i in seq_along(percentiles)) {
+      pred_matrix[,i] <- qshash(percentiles[i],
+                                mu = preds$mu,
+                                sigma = preds$sigma,
+                                epsilon = preds$epsilon,
+                                delta = preds$delta)
+    }
+
+    pred_data <- data.frame(age = pred_ages, pred_matrix)
+    names(pred_data)[-1] <- paste0("P", percentiles * 100)
+    return(pred_data)
+  }
+
   # Function to get predictions for cnorm models
   get_cnorm_predictions <- function(model, pred_ages) {
     m <- model$model
@@ -1379,7 +1412,9 @@ compare <- function(model1, model2,
   # Determine age range
   get_age_range <- function(model) {
     if(inherits(model, c("cnormBetaBinomial", "cnormBetaBinomial2"))) {
-      return(c(model$ageMin, model$ageMax))
+      return(c(attr(model$result, "ageMin"), attr(model$result, "ageMax")))
+    } else if(inherits(model, "cnormShaSh")) {
+      return(c(attr(model$result, "ageMin"), attr(model$result, "ageMax")))
     } else {
       m <- model$model
       return(c(m$minA1, m$maxA1))
@@ -1398,12 +1433,16 @@ compare <- function(model1, model2,
   # Get predictions for both models
   plot_data1 <- if(inherits(model1, c("cnormBetaBinomial", "cnormBetaBinomial2"))) {
     get_bb_predictions(model1, pred_ages)
+  } else if(inherits(model1, "cnormShaSh")) {
+    get_shash_predictions(model1, pred_ages)
   } else {
     get_cnorm_predictions(model1, pred_ages)
   }
 
   plot_data2 <- if(inherits(model2, c("cnormBetaBinomial", "cnormBetaBinomial2"))) {
     get_bb_predictions(model2, pred_ages)
+  } else if(inherits(model2, "cnormShaSh")) {
+    get_shash_predictions(model2, pred_ages)
   } else {
     get_cnorm_predictions(model2, pred_ages)
   }
@@ -1486,6 +1525,43 @@ compare <- function(model1, model2,
       panel.grid.minor = element_line(color = "gray95")
     )
 
+  # Information criteria
+  if(inherits(model1, "cnorm")) {
+    ideal.model <- model1$model$ideal.model
+    rss <- model1$model$subsets$rss[ideal.model]
+    n <- nrow(model1$data)
+
+    sigma2 <- rss / (nrow(model1$data) - ideal.model - 1)  # residual variance
+    loglik <- -0.5 * n * (log(2 * pi) + log(sigma2) + 1)
+
+    AIC1 <- -2 * loglik + 2 * ideal.model
+    BIC1 <- model1$model$subsets$bic[ideal.model]
+  } else{
+    n_obs <- attr(model1$result, "N")
+    n_params <- length(model1$result$par)
+    log_likelihood <- -model1$result$value
+    AIC1 <- 2 * n_params - 2 * log_likelihood
+    BIC1 <- n_params * log(n_obs) - 2 * log_likelihood
+  }
+
+  if(inherits(model2, "cnorm")) {
+    ideal.model <- model2$model$ideal.model
+    rss <- model2$model$subsets$rss[ideal.model]
+    n <- nrow(model2$data)
+
+    sigma2 <- rss / (nrow(model2$data) - ideal.model - 1)  # residual variance
+    loglik <- -0.5 * n * (log(2 * pi) + log(sigma2) + 1)
+
+    AIC2 <- -2 * loglik + 2 * ideal.model
+    BIC2 <- model2$model$subsets$bic[ideal.model]
+  } else{
+    n_obs <- attr(model2$result, "N")
+    n_params <- length(model2$result$par)
+    log_likelihood <- -model2$result$value
+    AIC2 <- 2 * n_params - 2 * log_likelihood
+    BIC2 <- n_params * log(n_obs) - 2 * log_likelihood
+  }
+
   if (!is.null(score) & !is.null(age)) {
     # Prepare data for manifest percentiles and fit statistics
     data <- data.frame(age = age, score = score)
@@ -1550,7 +1626,12 @@ compare <- function(model1, model2,
                                   minNorm = model1$model$minL1,
                                   maxNorm = model1$model$maxL1)
       data$fitted1 <- 10*(data$fitted1 - attributes(model1$data)$scaleMean) / attributes(model1$data)$scaleSD
-    }else{
+    }else if(inherits(model1, c("cnormBetaBinomial", "cnormBetaBinomial2"))) {
+      data$fitted1 <- predict(model1, data$age, data$score)
+      scaleMean <- attr(model1$result, "scaleMean")
+      scaleSD <- attr(model1$result, "scaleSD")
+      data$fitted1 <- 10*(data$fitted1 - scaleMean) / scaleSD
+    }else if(inherits(model1, "cnormShaSh")) {
       data$fitted1 <- predict(model1, data$age, data$score)
       scaleMean <- attr(model1$result, "scaleMean")
       scaleSD <- attr(model1$result, "scaleSD")
@@ -1562,7 +1643,12 @@ compare <- function(model1, model2,
                                   minNorm = model2$model$minL1,
                                   maxNorm = model2$model$maxL1)
       data$fitted2 <- 10*(data$fitted2 - attributes(model2$data)$scaleMean) / attributes(model2$data)$scaleSD
-    }else{
+    }else if(inherits(model2, c("cnormBetaBinomial", "cnormBetaBinomial2"))) {
+      data$fitted2 <- predict(model2, data$age, data$score)
+      scaleMean <- attr(model2$result, "scaleMean")
+      scaleSD <- attr(model2$result, "scaleSD")
+      data$fitted2 <- 10*(data$fitted2 - scaleMean) / scaleSD
+    }else if(inherits(model2, "cnormShaSh")) {
       data$fitted2 <- predict(model2, data$age, data$score)
       scaleMean <- attr(model2$result, "scaleMean")
       scaleSD <- attr(model2$result, "scaleSD")
@@ -1582,15 +1668,18 @@ compare <- function(model1, model2,
     MAD1 <- mean(abs(data$fitted1 - data$normValue), na.rm = TRUE)
     MAD2 <- mean(abs(data$fitted2 - data$normValue), na.rm = TRUE)
 
+
     # Create and print summary table
     fit_table <- data.frame(
-      Metric = c("R2", "Bias", "RMSE", "MAD"),
-      Model1 = c(R2a, bias1, RMSE1, MAD1),
-      Model2 = c(R2b, bias2, RMSE2, MAD2),
+      Metric = c("R2", "Bias", "RMSE", "MAD", "AIC", "BIC"),
+      Model1 = c(R2a, bias1, RMSE1, MAD1, AIC1, BIC1),
+      Model2 = c(R2b, bias2, RMSE2, MAD2, AIC2, BIC2),
       Difference = c(R2b - R2a,
                      bias2 - bias1,
                      RMSE2 - RMSE1,
-                     MAD2 - MAD1)
+                     MAD2 - MAD1,
+                     AIC2 - AIC1,
+                     BIC2 - BIC1)
     )
 
     # Round values
@@ -1602,6 +1691,22 @@ compare <- function(model1, model2,
     cat("\nNote: Difference = Model2 - Model1\n")
     cat("      Fit indices are based on the manifest and fitted norm scores of both models.\n")
     cat("      Scale metrics are T scores (scaleSD = 10)\n")
+    cat("      AIC and BIC should only be used when comparing models of the same type.\n")
+  }else{
+    # Create and print summary table
+    fit_table <- data.frame(
+      Metric = c("AIC", "BIC"),
+      Model1 = c(AIC1, BIC1),
+      Model2 = c(AIC2, BIC2),
+      Difference = c(AIC2 - AIC1,
+                     BIC2 - BIC1)
+    )
+
+    cat("\nModel Comparison Summary:\n")
+    cat("------------------------\n")
+    print(format(fit_table, justify = "right"), row.names = FALSE)
+    cat("\nNote: Difference = Model2 - Model1\n")
+    cat("      AIC and BIC should only be used when comparing models of the same type.\n")
   }
 
   return(p)
