@@ -208,7 +208,9 @@ normTable <- function(A,
 
   if(inherits(model, "cnormBetaBinomial")||inherits(model, "cnormBetaBinomial2")){
     return(normTable.betabinomial(model, A, CI = CI, reliability = reliability))
-  }else if(inherits(model, "cnorm")){
+  }else if(inherits(model, "cnormShaSh")){
+    return(normTable.shash(model, A, minRaw, maxRaw, step, CI = CI, reliability = reliability))
+  } else if(inherits(model, "cnorm")){
     model <- model$model
   }else if(!inherits(model, "cnormModel")){
     stop("Please provide a cnorm object.")
